@@ -10,6 +10,8 @@ import sys
 import tarfile
 import traceback
 from builtins import str
+from types import ModuleType
+from typing import Tuple
 
 import boto3
 from werkzeug.wrappers import Response
@@ -18,11 +20,11 @@ from werkzeug.wrappers import Response
 # so handle both scenarios.
 try:
     from zappa.middleware import ZappaWSGIMiddleware
-    from zappa.utilities import merge_headers, parse_s3_url
+    from zappa.utilities import DEFAULT_TEXT_MIMETYPES, merge_headers, parse_s3_url
     from zappa.wsgi import common_log, create_wsgi_request
 except ImportError:  # pragma: no cover
     from .middleware import ZappaWSGIMiddleware
-    from .utilities import merge_headers, parse_s3_url
+    from .utilities import DEFAULT_TEXT_MIMETYPES, merge_headers, parse_s3_url
     from .wsgi import common_log, create_wsgi_request
 
 
@@ -265,6 +267,47 @@ class LambdaHandler:
                 print(cex)
         return exception_processed
 
+    @staticmethod
+    def _process_response_body(response: Response, settings: ModuleType) -> Tuple[str, bool]:
+        """
+        Perform Response body encoding/decoding
+
+        Related: https://github.com/zappa/Zappa/issues/908
+        API Gateway requires binary data be base64 encoded:
+        https://aws.amazon.com/blogs/compute/handling-binary-data-using-amazon-api-gateway-http-apis/
+        When BINARY_SUPPORT is enabled the body is base64 encoded in the following cases:
+
+        - Content-Encoding defined, commonly used to specify compression (br/gzip/deflate/etc)
+          https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-Encoding
+          Content like this must be transmitted as b64.
+
+        - Response assumed binary when Response.mimetype does
+          not start with an entry defined in 'handle_as_text_mimetypes'
+        """
+        encode_body_as_base64 = False
+        if settings.BINARY_SUPPORT:
+            handle_as_text_mimetypes = DEFAULT_TEXT_MIMETYPES
+            additional_text_mimetypes = getattr(settings, "ADDITIONAL_TEXT_MIMETYPES", None)
+            if additional_text_mimetypes:
+                handle_as_text_mimetypes += tuple(additional_text_mimetypes)
+
+            if response.headers.get("Content-Encoding"):  # Assume br/gzip/deflate/etc encoding
+                encode_body_as_base64 = True
+
+            # werkzeug Response.mimetype: lowercase without parameters
+            # https://werkzeug.palletsprojects.com/en/2.2.x/wrappers/#werkzeug.wrappers.Request.mimetype
+            elif not response.mimetype.startswith(handle_as_text_mimetypes):
+                encode_body_as_base64 = True
+
+        if encode_body_as_base64:
+            body = base64.b64encode(response.data).decode("utf8")
+        else:
+            # response.data decoded by werkzeug
+            # https://werkzeug.palletsprojects.com/en/2.2.x/wrappers/#werkzeug.wrappers.Request.get_data
+            body = response.get_data(as_text=True)
+
+        return body, encode_body_as_base64
+
     @staticmethod
     def run_function(app_function, event, context):
         """
@@ -557,15 +600,10 @@ class LambdaHandler:
                         zappa_returndict.setdefault("statusDescription", response.status)
 
                     if response.data:
-                        if (
-                            settings.BINARY_SUPPORT
-                            and not response.mimetype.startswith("text/")
-                            and response.mimetype != "application/json"
-                        ):
-                            zappa_returndict["body"] = base64.b64encode(response.data).decode("utf-8")
-                            zappa_returndict["isBase64Encoded"] = True
-                        else:
-                            zappa_returndict["body"] = response.get_data(as_text=True)
+                        processed_body, is_base64_encoded = self._process_response_body(response, settings=settings)
+                        zappa_returndict["body"] = processed_body
+                        if is_base64_encoded:
+                            zappa_returndict["isBase64Encoded"] = is_base64_encoded
 
                     zappa_returndict["statusCode"] = response.status_code
                     if "headers" in event:
